package Microsoft::AdCenter::V6::CustomerManagementService::SecretQuestions;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V6::CustomerManagementService::SecretQuestions - Represents "SecretQuestions" in Microsoft AdCenter Customer Management Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

Anniversary
FatherMiddleName
FavoriteMovie
FavoritePetsName
FavoriteSportsTeam
FavoriteTeacherName
FirstChildMiddleName
HighSchoolName
None
SpouseMiddleName

=cut

sub Anniversary {
    return 'Anniversary';
}

sub FatherMiddleName {
    return 'FatherMiddleName';
}

sub FavoriteMovie {
    return 'FavoriteMovie';
}

sub FavoritePetsName {
    return 'FavoritePetsName';
}

sub FavoriteSportsTeam {
    return 'FavoriteSportsTeam';
}

sub FavoriteTeacherName {
    return 'FavoriteTeacherName';
}

sub FirstChildMiddleName {
    return 'FirstChildMiddleName';
}

sub HighSchoolName {
    return 'HighSchoolName';
}

sub None {
    return 'None';
}

sub SpouseMiddleName {
    return 'SpouseMiddleName';
}

1;
